@@ -3,7 +3,7 @@ from collections.abc import AsyncIterable
 from aiohttp_client_cache import BaseCache, CacheBackend, ResponseOrKey
 from aiohttp_client_cache.docs import extend_init_signature
 
-from pylav.sql import tables
+import pylav.sql.tables.cache
 
 
 def postgres_template():
@@ -29,50 +29,56 @@ class PostgresStorage(BaseCache):
 
     async def contains(self, key: str) -> bool:
         """Check if a key is stored in the cache"""
-        response = await tables.AioHttpCacheRow.raw(
-            "SELECT EXISTS(SELECT 1 FROM aiohttp_client_cache WHERE key ={} LIMIT 1) AS exists", key
+        return await pylav.sql.tables.cache.AioHttpCacheRow.exists().where(
+            pylav.sql.tables.cache.AioHttpCacheRow.key == key
         )
-        return response[0]["exists"] if response else False
 
     async def clear(self) -> None:
         """Delete all items from the cache"""
-        await tables.AioHttpCacheRow.raw("TRUNCATE TABLE aiohttp_client_cache")
+        await pylav.sql.tables.cache.AioHttpCacheRow.raw("TRUNCATE TABLE aiohttp_client_cache")
 
     async def delete(self, key: str) -> None:
         """Delete an item from the cache"""
-        await tables.AioHttpCacheRow.raw("DELETE FROM aiohttp_client_cache WHERE key = {}", key)
+        await pylav.sql.tables.cache.AioHttpCacheRow.delete().where(pylav.sql.tables.cache.AioHttpCacheRow.key == key)
 
     async def keys(self) -> AsyncIterable[str]:
         """Get all keys stored in the cache"""
-        async with await tables.AioHttpCacheRow.select(tables.AioHttpCacheRow.key).batch(batch_size=10) as batch:
-            async for _batch in batch:
-                yield _batch["key"]
+        async with await pylav.sql.tables.cache.AioHttpCacheRow.select(
+            pylav.sql.tables.cache.AioHttpCacheRow.key
+        ).output(load_json=True, nested=True).batch(batch_size=10) as batch:
+            async for entry in batch:
+                yield entry["key"]
 
     async def read(self, key: str) -> ResponseOrKey:
         """Read an item from the cache"""
-        response = await tables.AioHttpCacheRow.raw(
-            "SELECT value FROM aiohttp_client_cache WHERE key = {} LIMIT 1", key
+        response = (
+            await pylav.sql.tables.cache.AioHttpCacheRow.select(pylav.sql.tables.cache.AioHttpCacheRow.value)
+            .where(pylav.sql.tables.cache.AioHttpCacheRow.key == key)
+            .first()
+            .output(load_json=True, nested=True)
         )
         return self.deserialize(response["value"]) if response else None
 
     async def size(self) -> int:
         """Get the number of items in the cache"""
-        response = await tables.AioHttpCacheRow.raw("SELECT COUNT(*) FROM aiohttp_client_cache")
-        return response[0]["count"] if response else 0
+        return await pylav.sql.tables.cache.AioHttpCacheRow.count()
 
     def values(self) -> AsyncIterable[ResponseOrKey]:
         """Get all values stored in the cache"""
         return self._values()
 
     async def _values(self) -> AsyncIterable[ResponseOrKey]:
-        async with await tables.AioHttpCacheRow.select(tables.AioHttpCacheRow.value).batch(batch_size=10) as batch:
-            async for _batch in batch:
-                yield self.deserialize(_batch["value"])
+        async with await pylav.sql.tables.cache.AioHttpCacheRow.select(
+            pylav.sql.tables.cache.AioHttpCacheRow.value
+        ).output(load_json=True, nested=True).batch(batch_size=10) as batch:
+            async for entry in batch:
+                yield self.deserialize(entry["value"])
 
     async def write(self, key: str, item: ResponseOrKey):
         """Write an item to the cache"""
-
-        await tables.AioHttpCacheRow.raw(
+        # TODO: When piccolo add support to on conflict clauses using RAW here is more efficient
+        #  Tracking issue: https://github.com/piccolo-orm/piccolo/issues/252
+        await pylav.sql.tables.cache.AioHttpCacheRow.raw(
             """
             INSERT INTO aiohttp_client_cache (key, value)
             VALUES ({}, {})
@@ -84,9 +90,6 @@ class PostgresStorage(BaseCache):
 
     async def bulk_delete(self, keys: set[str]) -> None:
         """Delete multiple items from the cache"""
-        await tables.AioHttpCacheRow.raw(
-            f"""
-            DELETE FROM aiohttp_client_cache
-            WHERE {tables.AioHttpCacheRow.key.is_in(list(keys)).querystring}
-            """,
+        await pylav.sql.tables.cache.AioHttpCacheRow.delete().where(
+            pylav.sql.tables.cache.AioHttpCacheRow.key.is_in(list(keys))
         )
