@@ -2,9 +2,9 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+import pylav.sql.tables.nodes
 from pylav._logging import getLogger
 from pylav.constants import BUNDLED_NODES_IDS
-from pylav.sql import tables
 from pylav.sql.models import NodeModel
 
 if TYPE_CHECKING:
@@ -34,13 +34,15 @@ class NodeConfigManager:
         self.currently_in_db.add(node.id)
         return node
 
-    async def get_all_unamanaged_nodes(self, dedupe: bool = True) -> list[NodeModel]:
+    async def get_all_unmanaged_nodes(self, dedupe: bool = True) -> list[NodeModel]:
         model_list = [
             NodeModel(**node)
-            for node in await tables.NodeRow.raw(
-                f"""SELECT id FROM node
-                WHERE {(tables.NodeRow.managed == False) & (tables.NodeRow.id.not_in(BUNDLED_NODES_IDS))}"""
+            for node in await pylav.sql.tables.nodes.NodeRow.select(pylav.sql.tables.nodes.NodeRow.id)
+            .where(
+                (pylav.sql.tables.nodes.NodeRow.managed == False)
+                & (pylav.sql.tables.nodes.NodeRow.id.not_in(BUNDLED_NODES_IDS))
             )
+            .output(nested=True, load_json=True)
         ]
         new_model_list = list(set(model_list)) if dedupe else model_list
         for n in new_model_list:
@@ -48,19 +50,21 @@ class NodeConfigManager:
         return new_model_list
 
     async def get_all_nodes(self) -> list[NodeModel]:
-        model_list = await self.get_all_unamanaged_nodes(dedupe=True)
+        model_list = await self.get_all_unmanaged_nodes(dedupe=True)
         if mn := self.bundled_node_config():
             model_list.append(mn)
         return model_list
 
     async def get_bundled_node_config(self) -> NodeModel | None:
-        response = await tables.NodeRow.raw(
-            """SELECT id FROM node WHERE
-            id = {} AND managed = {} LIMIT 1""",
-            self._client.bot.user.id,
-            True,
+        response = (
+            await pylav.sql.tables.nodes.NodeRow.select(pylav.sql.tables.nodes.NodeRow.id)
+            .where(
+                (pylav.sql.tables.nodes.NodeRow.id == self._client.bot.user.id)
+                & (pylav.sql.tables.nodes.NodeRow.managed is True)
+            )
+            .first()
         )
-        return NodeModel(**response[0]) if response else None
+        return NodeModel(**response) if response else None
 
     async def update_node(
         self,
@@ -142,7 +146,6 @@ class NodeConfigManager:
     @staticmethod
     async def count() -> int:
         """Return the number of unbundled nodes in the database."""
-        response = await tables.NodeRow.raw(
-            f"""SELECT COUNT(id) FROM node WHERE {tables.NodeRow.id.not_in(BUNDLED_NODES_IDS).querystring}"""
+        return await pylav.sql.tables.nodes.NodeRow.count().where(
+            pylav.sql.tables.nodes.NodeRow.id.not_in(BUNDLED_NODES_IDS)
         )
-        return response[0]["count"] if response else 0
